@@ -1,8 +1,8 @@
 """Top-level package for eBEL API client."""
 
-from ebel_rest.core import connect
-from ebel_rest.export import export_graph
+from ebel_rest.manager.core import connect
+from ebel_rest.manager.export import export_graph
 
 __author__ = """Christian Ebeling"""
 __email__ = 'Christian.Ebeling@scai.fraunhofer.de'
-__version__ = '1.0.10'
+__version__ = '1.0.11'
